feast.core.Source_pb2 — Feast 0.3.2 documentation

# Source code for feast.core.Source_pb2

    # -*- coding: utf-8 -*-
    # Generated by the protocol buffer compiler.  DO NOT EDIT!
    # source: feast/core/Source.proto

    import sys
    _b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
    from google.protobuf.internal import enum_type_wrapper
    from google.protobuf import descriptor as _descriptor
    from google.protobuf import message as _message
    from google.protobuf import reflection as _reflection
    from google.protobuf import symbol_database as _symbol_database
    # @@protoc_insertion_point(imports)

    _sym_db = _symbol_database.Default()

    DESCRIPTOR = _descriptor.FileDescriptor(
      name='feast/core/Source.proto',
      package='feast.core',
      syntax='proto3',
      serialized_options=_b('\n\nfeast.coreB\013SourceProtoZ/github.com/gojek/feast/sdk/go/protos/feast/core'),
      serialized_pb=_b('\n\x17\x66\x65\x61st/core/Source.proto\x12\nfeast.core\"}\n\x06Source\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.feast.core.SourceType\x12<\n\x13kafka_source_config\x18\x02 \x01(\x0b\x32\x1d.feast.core.KafkaSourceConfigH\x00\x42\x0f\n\rsource_config\"=\n\x11KafkaSourceConfig\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t*$\n\nSourceType\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05KAFKA\x10\x01\x42J\n\nfeast.coreB\x0bSourceProtoZ/github.com/gojek/feast/sdk/go/protos/feast/coreb\x06proto3')
    )

    _SOURCETYPE = _descriptor.EnumDescriptor(
      name='SourceType',
      full_name='feast.core.SourceType',
      filename=None,
      file=DESCRIPTOR,
      values=[
        _descriptor.EnumValueDescriptor(
          name='INVALID', index=0, number=0,
          serialized_options=None,
          type=None),
        _descriptor.EnumValueDescriptor(
          name='KAFKA', index=1, number=1,
          serialized_options=None,
          type=None),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=229,
      serialized_end=265,
    )
    _sym_db.RegisterEnumDescriptor(_SOURCETYPE)

    SourceType = enum_type_wrapper.EnumTypeWrapper(_SOURCETYPE)
    INVALID = 0
    KAFKA = 1

    _SOURCE = _descriptor.Descriptor(
      name='Source',
      full_name='feast.core.Source',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      fields=[
        _descriptor.FieldDescriptor(
          name='type', full_name='feast.core.Source.type', index=0,
          number=1, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
          name='kafka_source_config', full_name='feast.core.Source.kafka_source_config', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='source_config', full_name='feast.core.Source.source_config',
          index=0, containing_type=None, fields=[]),
      ],
      serialized_start=39,
      serialized_end=164,
    )

    _KAFKASOURCECONFIG = _descriptor.Descriptor(
      name='KafkaSourceConfig',
      full_name='feast.core.KafkaSourceConfig',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      fields=[
        _descriptor.FieldDescriptor(
          name='bootstrap_servers', full_name='feast.core.KafkaSourceConfig.bootstrap_servers', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=_b("").decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
          name='topic', full_name='feast.core.KafkaSourceConfig.topic', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=_b("").decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=166,
      serialized_end=227,
    )

    _SOURCE.fields_by_name['type'].enum_type = _SOURCETYPE
    _SOURCE.fields_by_name['kafka_source_config'].message_type = _KAFKASOURCECONFIG
    _SOURCE.oneofs_by_name['source_config'].fields.append(
      _SOURCE.fields_by_name['kafka_source_config'])
    _SOURCE.fields_by_name['kafka_source_config'].containing_oneof = _SOURCE.oneofs_by_name['source_config']
    DESCRIPTOR.message_types_by_name['Source'] = _SOURCE
    DESCRIPTOR.message_types_by_name['KafkaSourceConfig'] = _KAFKASOURCECONFIG
    DESCRIPTOR.enum_types_by_name['SourceType'] = _SOURCETYPE
    _sym_db.RegisterFileDescriptor(DESCRIPTOR)

    Source = _reflection.GeneratedProtocolMessageType('Source', (_message.Message,), {
      'DESCRIPTOR' : _SOURCE,
      '__module__' : 'feast.core.Source_pb2'
      # @@protoc_insertion_point(class_scope:feast.core.Source)
      })
    _sym_db.RegisterMessage(Source)

    KafkaSourceConfig = _reflection.GeneratedProtocolMessageType('KafkaSourceConfig', (_message.Message,), {
      'DESCRIPTOR' : _KAFKASOURCECONFIG,
      '__module__' : 'feast.core.Source_pb2'
      # @@protoc_insertion_point(class_scope:feast.core.KafkaSourceConfig)
      })
    _sym_db.RegisterMessage(KafkaSourceConfig)

    DESCRIPTOR._options = None
    # @@protoc_insertion_point(module_scope)